@@ -190,6 +190,17 @@ detfct.fit <- function(ddfobj, optim.options, bounds, misc.options){
 
   }
 
+  # calculate hessian if it didn't work during optimisation
+  if(!misc.options$mono & (is.null(lt$hessian) || any(is.na(lt$hessian)))){
+    # However, don't want to do this for uniform with no adjustments
+    if(lt$aux$ddfobj$type == "unif" && is.null(lt$aux$ddfobj$adjustment)){
+      # Do nothing - no hessian as nothing being estimated
+    }else{
+      lt$hessian <- numDeriv::hessian(flnl, lt$par, ddfobj=ddfobj,
+                                      misc.options=misc.options)
+    }
+  }
+
   if(showit >= 1){
     if(is.null(ddfobj$adjustment) & ddfobj$type=="unif"){
       cat("\nDEBUG: Convergence!",
